==> skimage_0.18.3.orig.tar.gz: scikit-image-0.18.3/skimage/morphology/__init__.py <==
from .binary import (binary_erosion, binary_dilation, binary_opening,
                     binary_closing)
from .grey import (erosion, dilation, opening, closing, white_tophat,
                   black_tophat)
from .selem import (square, rectangle, diamond, disk, cube, octahedron, ball,
                    octagon, star)
from ..measure._label import label
from ._skeletonize import skeletonize, medial_axis, thin, skeletonize_3d
from .convex_hull import convex_hull_image, convex_hull_object
from .greyreconstruct import reconstruction
from .misc import remove_small_objects, remove_small_holes
from .extrema import h_minima, h_maxima, local_maxima, local_minima
from ._flood_fill import flood, flood_fill
from .max_tree import (max_tree, area_opening, area_closing,
                       diameter_opening, diameter_closing,
                       max_tree_local_maxima)
from ._deprecated import watershed

__all__ = ['binary_erosion',
           'binary_dilation',
           'binary_opening',
           'binary_closing',
           'erosion',
           'dilation',
           'opening',
           'closing',
           'white_tophat',
           'black_tophat',
           'square',
           'rectangle',
           'diamond',
           'disk',
           'cube',
           'octahedron',
           'ball',
           'octagon',
           'star',
           'label',
           'watershed',
           'skeletonize',
           'skeletonize_3d',
           'thin',
           'medial_axis',
           'convex_hull_image',
           'convex_hull_object',
           'reconstruction',
           'remove_small_objects',
           'remove_small_holes',
           'h_minima',
           'h_maxima',
           'local_maxima',
           'local_minima',
           'flood',
           'flood_fill',
           'max_tree',
           'area_opening',
           'area_closing',
           'diameter_opening',
           'diameter_closing',
           'max_tree_local_maxima',
           ]

==> skimage_0.19.3.orig.tar.gz: scikit-image-0.19.3/skimage/morphology/__init__.py <==
from .binary import (binary_erosion, binary_dilation, binary_opening,
                     binary_closing)
from .gray import (erosion, dilation, opening, closing, white_tophat,
                   black_tophat)
from .footprints import (
    square, rectangle, diamond, disk, cube, octahedron, ball, octagon, star
)
from ..measure._label import label
from ._skeletonize import skeletonize, medial_axis, thin, skeletonize_3d
from .convex_hull import convex_hull_image, convex_hull_object
from .grayreconstruct import reconstruction
from .misc import remove_small_objects, remove_small_holes
from .extrema import h_minima, h_maxima, local_maxima, local_minima
from ._flood_fill import flood, flood_fill
from .max_tree import (max_tree, area_opening, area_closing,
                       diameter_opening, diameter_closing,
                       max_tree_local_maxima)

__all__ = ['binary_erosion',
           'binary_dilation',
           'binary_opening',
           'binary_closing',
           'erosion',
           'dilation',
           'opening',
           'closing',
           'white_tophat',
           'black_tophat',
           'square',
           'rectangle',
           'diamond',
           'disk',
           'cube',
           'octahedron',
           'ball',
           'octagon',
           'star',
           'label',
           'skeletonize',
           'skeletonize_3d',
           'thin',
           'medial_axis',
           'convex_hull_image',
           'convex_hull_object',
           'reconstruction',
           'remove_small_objects',
           'remove_small_holes',
           'h_minima',
           'h_maxima',
           'local_maxima',
           'local_minima',
           'flood',
           'flood_fill',
           'max_tree',
           'area_opening',
           'area_closing',
           'diameter_opening',
           'diameter_closing',
           'max_tree_local_maxima',
           ]
